@@ -240,15 +240,17 @@ gboolean gok_data_read_settings (void)
         gok_gconf_get_string (gconf_client, GOK_GCONF_AUX_DICTS, 
 			         &m_AuxDicts);
 
-	gok_gconf_get_string (gconf_client, GOK_GCONF_DOCK_TYPE,
-			      &a_gchar);
-        m_eDockType = gok_data_dock_type_from_string (a_gchar);
-	g_free (a_gchar);
+	if (gok_gconf_get_string (gconf_client, GOK_GCONF_DOCK_TYPE,
+			      &a_gchar)) {
+            m_eDockType = gok_data_dock_type_from_string (a_gchar);
+	    g_free (a_gchar);
+	}
 
-	gok_gconf_get_string (gconf_client, GOK_GCONF_COMPOSE_KBD_TYPE,
-			      &a_gchar);
-        compose_keyboard_type = gok_data_compose_type_from_string (a_gchar);
-	g_free (a_gchar);
+	if (gok_gconf_get_string (gconf_client, GOK_GCONF_COMPOSE_KBD_TYPE,
+			      &a_gchar)) {
+            compose_keyboard_type = gok_data_compose_type_from_string (a_gchar);
+	    g_free (a_gchar);
+	}
 
 	/* Read in settings for individual access methods */
 	access_method_dirs
