@@ -26,6 +26,7 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <gconf/gconf-client.h>
+#include "main.h"
 #include "gok-feedback.h"
 #include "gok-log.h"
 #include "gok-gconf.h"
@@ -663,14 +664,12 @@ void gok_feedback_backup (GokFeedback* pFeedback)
 			{
 				/* no, free the backup name and copy the name to backup */
 				g_free (pFeedback->pNameBackup);
-				pFeedback->pNameBackup = g_malloc (strlen (pFeedback->pName) + 1);
-				strcpy (pFeedback->pNameBackup, pFeedback->pName);
+				pFeedback->pNameBackup = g_strdup(pFeedback->pName);
 			}
 		}
 		else /* backup name is NULL */
 		{
-			pFeedback->pNameBackup = g_malloc (strlen (pFeedback->pName) + 1);
-			strcpy (pFeedback->pNameBackup, pFeedback->pName);
+			pFeedback->pNameBackup = g_strdup (pFeedback->pName);
 		}
 	}
 	
@@ -692,14 +691,12 @@ void gok_feedback_backup (GokFeedback* pFeedback)
 			{
 				/* no, free the backup name and copy the name to backup */
 				g_free (pFeedback->pDisplayNameBackup);
-				pFeedback->pDisplayNameBackup = g_malloc (strlen (pFeedback->pDisplayName) + 1);
-				strcpy (pFeedback->pDisplayNameBackup, pFeedback->pDisplayName);
+				pFeedback->pDisplayNameBackup = g_strdup (pFeedback->pDisplayName);
 			}
 		}
 		else /* backup name is NULL */
 		{
-			pFeedback->pDisplayNameBackup = g_malloc (strlen (pFeedback->pDisplayName) + 1);
-			strcpy (pFeedback->pDisplayNameBackup, pFeedback->pDisplayName);
+			pFeedback->pDisplayNameBackup = g_strdup (pFeedback->pDisplayName);
 		}
 	}
 
@@ -721,14 +718,12 @@ void gok_feedback_backup (GokFeedback* pFeedback)
 			{
 				/* no, free the backup name and copy the name to backup */
 				g_free (pFeedback->pNameSoundBackup);
-				pFeedback->pNameSoundBackup = g_malloc (strlen (pFeedback->pNameSound) + 1);
-				strcpy (pFeedback->pNameSoundBackup, pFeedback->pNameSound);
+				pFeedback->pNameSoundBackup = g_strdup (pFeedback->pNameSound);
 			}
 		}
 		else /* backup name is NULL */
 		{
-			pFeedback->pNameSoundBackup = g_malloc (strlen (pFeedback->pNameSound) + 1);
-			strcpy (pFeedback->pNameSoundBackup, pFeedback->pNameSound);
+			pFeedback->pNameSoundBackup = g_strdup (pFeedback->pNameSound);
 		}
 	}
 
@@ -766,16 +761,14 @@ gboolean gok_feedback_revert (GokFeedback* pFeedback)
 			{
 				/* no, free the name and copy the backup name to the name */
 				g_free (pFeedback->pName);
-				pFeedback->pName = g_malloc (strlen (pFeedback->pNameBackup) + 1);
-				strcpy (pFeedback->pName, pFeedback->pNameBackup);
+				pFeedback->pName = g_strdup (pFeedback->pNameBackup);
 				
 				bSettingsChanged = TRUE;
 			}
 		}
 		else /* name is NULL */
 		{
-			pFeedback->pName = g_malloc (strlen (pFeedback->pNameBackup) + 1);
-			strcpy (pFeedback->pName, pFeedback->pNameBackup);
+			pFeedback->pName = g_strdup (pFeedback->pNameBackup);
 			
 			bSettingsChanged = TRUE;
 		}
@@ -792,16 +785,14 @@ gboolean gok_feedback_revert (GokFeedback* pFeedback)
 			{
 				/* no, free the backup name and copy the name to backup */
 				g_free (pFeedback->pDisplayName);
-				pFeedback->pDisplayName = g_malloc (strlen (pFeedback->pDisplayNameBackup) + 1);
-				strcpy (pFeedback->pDisplayName, pFeedback->pDisplayNameBackup);
+				pFeedback->pDisplayName = g_strdup (pFeedback->pDisplayNameBackup);
 				
 				bSettingsChanged = TRUE;
 			}
 		}
 		else /* backup name is NULL */
 		{
-			pFeedback->pDisplayName = g_malloc (strlen (pFeedback->pDisplayNameBackup) + 1);
-			strcpy (pFeedback->pDisplayName, pFeedback->pDisplayNameBackup);
+			pFeedback->pDisplayName = g_strdup (pFeedback->pDisplayNameBackup);
 			
 			bSettingsChanged = TRUE;
 		}
@@ -818,16 +809,14 @@ gboolean gok_feedback_revert (GokFeedback* pFeedback)
 			{
 				/* no, free the backup name and copy the name to backup */
 				g_free (pFeedback->pNameSound);
-				pFeedback->pNameSound = g_malloc (strlen (pFeedback->pNameSoundBackup) + 1);
-				strcpy (pFeedback->pNameSound, pFeedback->pNameSoundBackup);
+				pFeedback->pNameSound = g_strdup (pFeedback->pNameSoundBackup);
 				
 				bSettingsChanged = TRUE;
 			}
 		}
 		else /* sound file name is NULL */
 		{
-			pFeedback->pNameSound = g_malloc (strlen (pFeedback->pNameSoundBackup) + 1);
-			strcpy (pFeedback->pNameSound, pFeedback->pNameSoundBackup);
+			pFeedback->pNameSound = g_strdup (pFeedback->pNameSoundBackup);
 			
 			bSettingsChanged = TRUE;
 		}
@@ -911,7 +900,11 @@ gint gok_feedback_perform_effect (gchar* pNameFeedback)
 			}
 
 			/* FIXME: evil use of static string here */
-			if (pFeedback->bSpeechOn == TRUE && m_keyLabel)
+			if (pFeedback->bSpeechOn == TRUE && m_keyLabel 
+#ifndef TEST_FEEDBACK
+			    && !gok_main_safe_mode ()
+#endif
+			    )
 			{
 				gok_speech_speak (m_keyLabel);
 			}
