@@ -93,8 +93,7 @@ gboolean gok_modifier_add (gchar* Name)
 	pNewModifier = (GokModifier*)g_malloc (sizeof (GokModifier));
 	
 	/* add the name to the modifier */
-	pNewModifier->Name = (gchar*)g_malloc (strlen (Name) + 1);
-	strcpy (pNewModifier->Name, Name);
+	pNewModifier->Name = g_strdup(Name);
 	
 	/* initialize the modifier */
 	pNewModifier->State = MODIFIER_STATE_OFF;
