@@ -271,7 +271,7 @@ int gok_predictor_predict ( Gok_Predictor gP )
 					gok_key_set_button_name(pKey); /* update style info */
 					/*gtk_widget_set_style(pKey->pButton, pKey->Style);*/
 					gok_key_set_button_label (pKey, keyID);
-					gok_key_add_label (pKey, keyID, 0, 0);
+					gok_key_add_label (pKey, keyID, 0, 0, NULL);
 									
 					pKey = pKey->pKeyNext;
 					pRealKey = NULL;
